@@ -1,11 +1,11 @@
 import dataclasses
-from typing import Optional, TypeVar
+from typing import Generic, Optional, TypeVar
 
 T = TypeVar("T")
 
 
 @dataclasses.dataclass
-class FeatureValidation:
+class FeatureValidation(Generic[T]):
     min: Optional[T]
     max: Optional[T]
     min_length: Optional[int]
