@@ -238,7 +238,7 @@ def _get_field(
 
     # If the default value isn't derived from Field, then it's only a
     # normal default value.  Convert it to a Field().
-    default = getattr(cls, annotation_name, MISSING)
+    default = getattr(cls, annotation_name, ...)
 
     if isinstance(default, Feature):
         # The feature was set like x: int = Feature(...)
@@ -251,8 +251,8 @@ def _get_field(
         # The feature was net set explicitly
         if isinstance(default, types.MemberDescriptorType):
             # This is a field in __slots__, so it has no default value.
-            default = MISSING
-        f = Feature(name=annotation_name, namespace=namespace)
+            default = ...
+        f = Feature(name=annotation_name, namespace=namespace, default=default)
 
     # Only at this point do we know the name and the type.  Set them.
     f.namespace = namespace
