@@ -1,11 +1,8 @@
 import inspect
 import logging
-from typing import Callable, Iterable, List, Optional, Set, TypeVar, Union, overload
+from typing import Any, Callable, Iterable, List, Optional, Set, Union, overload
 
-T = TypeVar("T")
-
-
-HookFn = Callable[[], T]
+HookFn = Callable[[], Any]
 EnvironmentFilter = Optional[Union[List[str], str]]
 
 
@@ -39,8 +36,8 @@ class Hook:
             else environment
         )
 
-    def __call__(self, *args, **kwargs):
-        return self.fn(*args, **kwargs)
+    def __call__(self):
+        return self.fn()
 
     def __repr__(self):
         return f'Hook(filename={self.filename}, fn={self.fn.__name__}", environment={str(self.environment)})'
@@ -69,8 +66,8 @@ def before_all(
 ) -> Union[Hook, Callable[[HookFn], Hook]]:
     caller_filename = inspect.stack()[1].filename
 
-    def decorator(f, cf=caller_filename):
-        hook = Hook(fn=f, filename=cf, environment=environment)
+    def decorator(f):
+        hook = Hook(fn=f, filename=caller_filename, environment=environment)
         Hook.before_all.add(hook)
         return hook
 
@@ -92,8 +89,8 @@ def after_all(
 ) -> Union[Hook, Callable[[HookFn], Hook]]:
     caller_filename = inspect.stack()[1].filename
 
-    def decorator(f, cf=caller_filename):
-        hook = Hook(fn=f, filename=cf, environment=environment)
+    def decorator(f):
+        hook = Hook(fn=f, filename=caller_filename, environment=environment)
         Hook.after_all.add(hook)
         return hook
 
