@@ -1,8 +1,11 @@
+from __future__ import annotations
+
 import dataclasses
 import inspect
 from dataclasses import dataclass
 from inspect import Parameter, isclass
 from typing import (
+    TYPE_CHECKING,
     Any,
     Callable,
     ClassVar,
@@ -27,7 +30,6 @@ import pyarrow
 from pydantic import BaseModel
 from typing_extensions import ParamSpec
 
-from chalk._autosql.autosql import query_as_feature_formatted
 from chalk.features.dataframe import DataFrame
 from chalk.features.feature_field import Feature
 from chalk.features.feature_set import Features
@@ -35,7 +37,6 @@ from chalk.features.feature_wrapper import FeatureWrapper, unwrap_feature
 from chalk.features.filter import Filter
 from chalk.features.tag import Environments, Tags
 from chalk.serialization.parsed_annotation import ParsedAnnotation
-from chalk.sql.base.protocols import BaseSQLSourceProtocol
 from chalk.state import StateWrapper
 from chalk.streams import StreamSource, Windowed, get_name_with_duration
 from chalk.streams.types import (
@@ -52,6 +53,10 @@ from chalk.utils.collections import ensure_tuple
 from chalk.utils.duration import Duration, ScheduleOptions
 from chalk.utils.environment_parsing import env_var_bool
 
+if TYPE_CHECKING:
+    from chalk.sql.base.protocols import BaseSQLSourceProtocol
+
+
 T = TypeVar("T")
 P = ParamSpec("P")
 
@@ -870,6 +875,8 @@ class StreamResolver(Resolver[P, T]):
         return _flatten_features(self.output)
 
     def __call__(self, *args: P.args, **kwargs: P.kwargs) -> T:
+        from chalk._autosql.autosql import query_as_feature_formatted
+
         raw_result = self.fn(*args, **kwargs)
         if self.window_index is not None and isinstance(raw_result, str) and str(args[self.window_index]) in raw_result:
             raw_result = DataFrame(
