@@ -68,8 +68,6 @@ class StringChalkQueryProtocol(Protocol):
     def all(self):
         """
         Return the results represented by this Query as a list.
-
-        :param incremental:
         :return:
         """
         ...
@@ -80,7 +78,7 @@ class StringChalkQueryProtocol(Protocol):
         *,
         incremental_column: str,
         lookback_period: Duration = "0s",
-        mode: Union[Literal["row"], Literal["group"]],
+        mode: Literal["row", "group"],
     ):
         ...
 
@@ -99,14 +97,14 @@ class StringChalkQueryProtocol(Protocol):
         *,
         incremental_column: Optional[str] = None,
         lookback_period: Optional[Duration] = "0s",
-        mode: Union[Literal["row"], Literal["group"], Literal["parameter"]],
+        mode: Literal["row", "group", "parameter"],
     ):
         """
         Operates like `all()`, but tracks "previous_latest_row_timestamp" between query executions in
         order to limit the amount of data returned.
 
         "previous_latest_row_timestamp" will be set the start of the query execution, or if you return
-        a "feature_time"-mapped column, Chalk will updated "previous_latest_row_timestamp" to the maximum
+        a "feature_time"-mapped column, Chalk will update "previous_latest_row_timestamp" to the maximum
         observed "feature_time" value.
 
         In "row" mode:
@@ -223,7 +221,7 @@ class ChalkQueryProtocol(Protocol[T]):
         order to limit the amount of data returned.
 
         "previous_latest_row_timestamp" will be set the start of the query execution, or if you return
-        a "feature_time"-mapped column, Chalk will updated "previous_latest_row_timestamp" to the maximum
+        a "feature_time"-mapped column, Chalk will update "previous_latest_row_timestamp" to the maximum
         observed "feature_time" value.
 
         In "row" mode:
