@@ -9,8 +9,17 @@ from chalk.sql.base.sql_source import BaseSQLSource, TableIngestMixIn
 T = TypeVar("T")
 
 
+def _verify_dep():
+    try:
+        import aiosqlite
+    except ModuleNotFoundError:
+        raise ChalkConfigurationException.missing_dependency("chalkpy[sqlite]")
+    del aiosqlite
+
+
 class SQLiteInMemorySourceImpl(BaseSQLSource, TableIngestMixIn):
     def __init__(self):
+        _verify_dep()
         super(SQLiteInMemorySourceImpl, self).__init__()
         self.ingested_tables: Dict[str, Any] = {}
 
@@ -20,11 +29,7 @@ class SQLiteInMemorySourceImpl(BaseSQLSource, TableIngestMixIn):
 
 class SQLiteFileSourceImpl(BaseSQLSource, TableIngestMixIn):
     def __init__(self, filename: Union[PathLike, str]):
-        try:
-            import aiosqlite
-        except ModuleNotFoundError:
-            raise ChalkConfigurationException.missing_dependency("chalkpy[sqlite]")
-        del aiosqlite
+        _verify_dep()
         self.filename = filename
         self.ingested_tables: Dict[str, Any] = {}
         super(SQLiteFileSourceImpl, self).__init__()
