@@ -2,10 +2,10 @@ from typing import Any
 
 from pydantic import BaseModel
 
-from chalk.streams._types import StreamSource
+from chalk.streams.base import StreamSource
 
 
-class FileSource(BaseModel, StreamSource):
+class FileSource(BaseModel, StreamSource, frozen=True):
     path: str
     key_separator: str = "|"
 
