@@ -44,6 +44,7 @@ class Taco:
     user_id: str
     price: int
     maybe_price: Optional[int]
+    maybe_str: Optional[str]
     hat: str
     topping_id: str
     ts: datetime = feature_time()
@@ -74,7 +75,7 @@ class TestDF:
         assert df_type.columns == ()
         assert df_type.__pydantic_model__ == Thing
         x = DataFrame(
-            polars.DataFrame(
+            pl.DataFrame(
                 {
                     "id": ["hello", "there"],
                     "wow": ["hello", "there"],
@@ -556,3 +557,52 @@ class TestDF:
         pl_df.write_parquet(filepath)
         new_df = DataFrame.read_parquet(filepath, columns={"my_col_name": "topping.value"})
         assert (df == new_df).all()
+
+    def test_slice(self):
+        df = DataFrame({Topping.value: [2, 3, 4]})
+        assert (df.slice() == df).all()
+        assert (df.slice(1) == DataFrame({Topping.value: [3, 4]})).all()
+        assert (df.slice(3) == DataFrame({Topping.value: []})).all()
+        # Out-of-range slices should be fine
+        assert (df.slice(4) == DataFrame({Topping.value: []})).all()
+        # Negative slicing should work, too
+        assert (df.slice(-1) == DataFrame({Topping.value: [4]})).all()
+        # Check that length is respected
+        assert (df.slice(0, 2) == DataFrame({Topping.value: [2, 3]})).all()
+        # If length is too big, then it should be equivalent to not specifying it
+        assert (df.slice(0, 4) == DataFrame({Topping.value: [2, 3, 4]})).all()
+
+    def test_to_features_no_hasone(self):
+        """Test that to_features() works without a has-one relationship"""
+        dt = datetime.now(timezone.utc)
+        assert DataFrame({Topping.value: [1, 2], Topping.ts: [dt, dt]}).to_features() == [
+            Topping(value=1, ts=dt),
+            Topping(value=2, ts=dt),
+        ]
+
+    def test_to_features_with_hasone(self):
+        df = DataFrame(
+            {
+                Topping.price.id: [2],
+                Topping.id: [1],
+                Topping.price.topping_id: [1],
+                Topping.value: [5],
+            }
+        )
+
+        assert df.to_features() == [Topping(id="1", value=5, price=ToppingPrice(id="2", topping_id="1"))]
+
+    def test_eq_null(self):
+        # Test that the Chalk DataFrame works around https://github.com/pola-rs/polars/issues/5870
+        df1 = DataFrame({Taco.maybe_str: [None], Taco.maybe_price: [None]})
+        df2 = DataFrame({Taco.maybe_str: [None], Taco.maybe_price: [None]})
+
+        assert (df1 == df2).all()
+
+    def test_all_empty(self):
+        assert DataFrame().all()
+        assert DataFrame({Taco.maybe_str: []}).all()
+
+    def test_any_empty(self):
+        assert not DataFrame().any()
+        assert not DataFrame({Taco.maybe_str: []}).any()
