@@ -30,7 +30,14 @@ def fn(messages: DataFrame[KafkaMessage]) -> DataFrame[StoreFeatures.id, StoreFe
 
 
 def test_runs_sql():
-    expected = polars.DataFrame({"id": ["store1", "store2"], "purchases": [10, 5]})
+    expected = DataFrame(
+        polars.DataFrame(
+            {
+                "store_features.id": ["store1", "store2"],
+                "store_features.purchases": [10, 5],
+            },
+        )
+    )
     actual = fn(
         DataFrame(
             polars.DataFrame(
@@ -43,4 +50,5 @@ def test_runs_sql():
         )
     )
 
-    assert expected.frame_equal(actual)
+    # polars.testing.assert_frame_equal(actual, expected)
+    assert expected.to_pyarrow() == actual.to_pyarrow()
